#
# spec file for package python-slycot
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-slycot
Version:        0.6.0
Release:        1.4
Summary:        A wrapper for the SLICOT control and systems library
License:        BSD-3-Clause AND GPL-2.0-only
Group:          Development/Languages/Python
URL:            https://github.com/python-control/Slycot
Source0:        https://files.pythonhosted.org/packages/source/s/slycot/slycot-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.10}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module scikit-build >= 0.15}
BuildRequires:  %{python_module setuptools >= 45}
BuildRequires:  %{python_module setuptools_scm >= 7.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  blas-devel
BuildRequires:  cmake >= 3.14
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-fortran
BuildRequires:  lapack-devel
BuildRequires:  python-rpm-macros
Requires:       python-numpy
# SECTION test
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
# /SECTION
%python_subpackages

%description
Slycot is a wrapper for the SLICOT control and systems library.

%prep
%setup -q -n slycot-%{version}
cp slycot/src/SLICOT-Reference/LICENSE LICENSE-SLICOT

%build
export CFLAGS="%{optflags}"
export FFLAGS="%{optflags}"
export CMAKE_GENERATOR="Unix Makefiles"
# openblas-devel is pulled in by numpy-devel, but we link against the
# generic BLAS/LAPACK binaries so that update-alternatives can choose
# the implementation for runtime.
export BLA_VENDOR="Generic"
%{python_expand # give the pep517 build the correct f2py flavor as "f2py3"
mkdir -p build/buildbin
ln -s %{_bindir}/f2py-%{$python_bin_suffix} build/buildbin/f2py3
}
export PATH=$PWD/build/buildbin:$PATH
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
export LANG="en_US.UTF-8"
%ifarch ppc64 ppc64le
  %define skiptest -k "not (test_tb05ad_ or test_sg03ad_ex)"
%endif
%pytest_arch --pyargs slycot %{?skiptest}

%files %{python_files}
%doc README.rst
%license COPYING LICENSE-SLICOT
%{python_sitearch}/slycot
%{python_sitearch}/slycot-%{version}.dist-info

%changelog
* Fri Apr  5 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.6.0
  [#]# New and updated wrappers
  * Bugfix ab13bd by @KybernetikJo in #200
  * Add ab04md by @KybernetikJo in #201
  * Add sb10yd by @KybernetikJo in #203
  * Implement MB02ED by @saasaa in #214
  [#]# Maintenance and upkeep improvements
  * Refactor init.py by @KybernetikJo in #205
  * Change analysis.py to numpydoc style by @KybernetikJo in #206
  * Change synthesis.py to numpydoc style by @KybernetikJo in #212
  * Change math.py to numpydoc style by @KybernetikJo in #211
  * Change transform.py to numpydoc style by @KybernetikJo in #213
  * Enable Python 3.12, drop Python <3.9 by @bnavigator in #227
  * Update to SLICOT v5.9 by @bnavigator in #231
* Thu Apr 27 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.5.4
  * Don't include package data by @bnavigator in #194
  * Update SLICOT to 5.8 Update 1 by @bnavigator in #195
* Wed Dec 21 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.5.3
  * This patch release updates the build system to be compatible
    with NumPy 1.24.0 -- gh#python-control/Slycot#187
- Drop rpmlintc: python-tests-in-package has been dropped
* Wed Nov 23 2022 Ben Greiner <code@bnavigator.de>
- Update to v0.5.2
  * Drop Support for Python 3.7
- Release v0.5.1
  * This release is a minor change in the build system. There are
    no new wrappers or code changes of existing SLICOT wrappers.
  * Use FindPython instead of deprecated FindPythonLibs by
    @bnavigator in #181
  * Use setuptools_scm instead of custom version determination code
    by @bnavigator in #180
  * Support Python 3.11 by @bnavigator in #182
* Sun Jul 10 2022 Ben Greiner <code@bnavigator.de>
- Restore finding correctly flavored f2py during build
* Sat Jul  9 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.5.0
  * We've switched our Fortran SLICOT base from the older,
    GPL-licensed version 5.0 to the now BSD-licensed version of
    SLICOT hosted on Github. This specific version of Slycot is
    based on SLICOT v5.8.
  * Slycot itself remains GPL-licensed for the time being.
  * We've added a wrapper for SLICOT AB13MD (#171), which computes
    the upper bound for the structured singular value of a system
    and given uncertainty structure.
  * SB03OD used to raise an error if the Schur factor supplied in
    array A was unstable; now, a warning is raised, and the
    eigenvalues are still returned (via #176, which updates to
    SLICOT v5.8).
  * MB03RD correctly handles X=None, the default (#139).
  * In SB03MD, the LDWORK value computed for discrete-time case was
    corrected (#166).
  * AG08BD testing was made more numerically robust.
  * A test for XERBLA behaviour was fixed.
- Switch to PEP517 build
* Thu Oct 28 2021 Ben Greiner <code@bnavigator.de>
- Use the correct alternative for f2py during build
* Mon Jan 18 2021 Benjamin Greiner <code@bnavigator.de>
- Skip python36 because of SciPy 1.6.0
* Thu Jul  2 2020 Benjamin Greiner <code@bnavigator.de>
- remove pytest_arch PYTHONPATH workaround, fixed in python-rpm-macros
* Tue Jun 30 2020 Benjamin Greiner <code@bnavigator.de>
- Remove the ppc workaround and skip the failing test entirely.
- Remove openblas configuration; link to Generic implementation.
  This lets update-alternatives select the implementation at runtime.
  Optimized packages are pulled in by numpy-devel and scipy.
* Fri Jun 26 2020 Benjamin Greiner <code@bnavigator.de>
- break test loop before test matrices are too ill-conditioned for
  the ppc architecture
- remove python2 support: there is no python2-scikit-build
- requires cmake >= 3.11 (no leap 15.1)
* Sat May 30 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 0.4.0.0
  * Added periodic Schur decomposition functions mb03vd, mb03vy, and mb03wd
  * Added ab08nz, allowing one to find zeros of complex-valued state-space models
  * Added mb03rd, Schur to block-diagonal transform
  * Added sb01fd H-infinity solver
    Already present sb10ad searches for a minimum gamma value for a given
    H-infinity problem; sb10fd, by contrast, only attempts to solve for a given
    gamma value. This can be used to test for admissible gamma values, which
    could be useful for problems like python-control/python-control#367.
  * New Slycot exception hierarchy; greatly improved Slycot error handling.
    Slycot routines now raise SlycotValueError where they would previously have
    raised ValueError, and SlycotArithmeticError where they would have raised
    ArithmeticError.
    These changes are backwardly compatible: SlycotValueError is a subclasss of
    ValueError, and SlycotArithmeticError is a subclass of ArithmeticError.
    As part of this, many of the Slycot function docstrings were changed to
    conform to numpydoc conventions.
    This supersedes an earlier fix for python-control#347 made during 0.4.0
    development.
  * Override XERBLA
    Overrode the BLAS error function XERBLA that SLICOT routines use to report
    errors; the BLAS-provided XERBLA can terminate the whole Python process.
  * Correct application of DGEBAL in TB01TD and TB05AD
  * Fixed ab01nd for jobz='N' case
  * conda build recipes no longer use pip
  * added conda recipes for MKL and Apple
  * removed conda recipes for Windows; no developer is using them, and they
    weren't working
  * the signature files (.pyf files) are now a dependency of wrapper generation
    Testing
  * Tests added for mb05nd, mc01td, ab08nd, ab08nz, mb03vd, mb03vy, mb03wd.
  * Tests fixed or expanded for mb05md, sg03ad, td04ad.
  * Switched to pytest; Slycot CI now uses pytest for both the Slycot and
    python-control test suites.
  * CI now builds and tests for Linux and macOS. The Linux builds include
    OpenBLAS and MKL variants.
  * Examples are run as part of tests. Outputs are not checked, but errors and
    warnings are.
  * CI coveralls.io integration fixed.
  * General test clean-up.
  * Test files are no longer executable.
  * Fix for mb05nd.
  * Lots of clean-up: removal of unused mathematical.pyf, many docstring fixes,
    and some PEP 8 conformance changes to Python code.
  * Fix for Fortran-compiler dependence on machine value used to represent
    logical values .TRUE. and .FALSE.
  * @repagh fired up his time machine and ensured punch-card compatibility of
    the SLICOT Fortran code by limiting line lengths to 72 characters.
- switch testing to pytest
- some new tests require scipy
- remove obsolete patches fix-test-sg03ad.patch and fix-test-td04ad.patch
* Mon Apr 20 2020 Benjamin Greiner <code@bnavigator.de>
- python2 dependency only for python2 enabling repos
* Tue Apr  7 2020 Benjamin Greiner <code@bnavigator.de>
- let the updated scikit-build do the f2py detection
* Tue Apr  7 2020 Benjamin Greiner <code@bnavigator.de>
- update the f2py detection. The numpy package removed /usr/bin/f2py3
* Wed Dec  4 2019 Benjamin Greiner <code@bnavigator.de>
- mirror blas/lapack/openblas requirements from numpy-devel depending
  on architecture and force CMake to find it.
- reduce the required precision in the sg03ad test so that
  powerpc passes
* Tue Dec  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update fix-test-sg03ad.patch once more again
* Fri Nov  8 2019 Benjamin Greiner <code@bnavigator.de>
- fix unittests to pass on all architectures
  * fix-test-sg03ad.patch see upstream PR#82
  * fix-test-td04ad.patch see upstream PR#83
* Sun Sep 22 2019 Benjamin Greiner <code@bnavigator.de>
- Make sure the correct F2PY flavor is executed
- Enforce Unix Makefile generator for CMake
* Sun Jul  7 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid name repetition in summary.
* Fri Jul  5 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Do not write unreproducible .pyc files for test code
  to make the package build reproducible (boo#1047218)
* Wed Jun 26 2019 Benjamin Greiner <code@bnavigator.de>
- clean up spec file
- force installation in %%python_sitearch
* Mon Jun 24 2019 Benjamin Greiner <code@bnavigator.de>
- release 0.3.5
* Fri Jun 21 2019 Benjamin Greiner <code@bnavigator.de>
- prerelease of v0.3.5
* Fri Jun 21 2019 Benjamin Greiner <code@bnavigator.de>
- fix destination directory issue by specifying packages keyword
* Fri Jun 21 2019 Benjamin Greiner <code@bnavigator.de>
- change the patch according to
  https://github.com/python-control/Slycot/pull/69
  and
  https://github.com/python-control/Slycot/pull/67
* Fri Jun 21 2019 Benjamin Greiner <code@bnavigator.de>
- v0.3.4.0: PyPI package does not include runtests.py. (Issue reported upstream)
- patch the CMake source file to look into sitearch instead of sitelib
